@@ -117,6 +117,20 @@ def find_users_by_email_starting_with(email_prefix=None, cursor=None, page_size=
                               page_size, cursor, cache_begin=None)
 
 
+def find_users_by_email_and_group(email_prefix=None, group=None, cursor=None, page_size=30):
+    """
+    Returns a command that retrieves users by its email_prefix, ordered by email and by Group.
+    If Group is None, only users without any group are going to be searched
+    It returns a max number of users defined by page_size arg. Next result can be retrieved using cursor, in
+    a next call. It is provided in cursor attribute from command.
+    """
+    email_prefix = email_prefix or ''
+
+    return ModelSearchCommand(MainUser.query_email_and_group(email_prefix, group),
+                              page_size, cursor, cache_begin=None)
+
+
+
 def send_passwordless_login_link(email, return_url, lang='en_US', url_login='https://pswdless.appspot.com/rest/login'):
     """
 
@@ -162,6 +176,7 @@ def save_or_update_facebook_app_data(id=None, token=None):
     return SaveOrUpdateFacebookApp(id, token)
 
 
+
 def login_facebook(token, response):
     """
 
@@ -169,4 +184,4 @@ def login_facebook(token, response):
     :param response: http response from webapp2
     :return: a command that log the facebook user in
     """
-    return LogFacebookUserIn(token, response, USER_COOKIE_NAME)
\ No newline at end of file
+    return LogFacebookUserIn(token, response, USER_COOKIE_NAME)
