@@ -9,7 +9,7 @@ from gaebusiness.business import CommandParallel
 from gaebusiness.gaeutil import ModelSearchCommand, UrlFetchCommand
 from gaecookie import facade
 from gaegraph.business_base import SingleDestinationSearch
-from gaepermission.base_commands import GetMainUserByEmail
+from gaepermission.base_commands import GetMainUserByEmail, ExternalToMainUser, MainUserSearch
 from gaepermission.model import MainUser, ExternalToMainUser, PasswordlessUser
 from gaepermission.passwordless.model import PasswordlessApp
 
@@ -99,11 +99,11 @@ class PasswordlessDetailCheck(GetApp):
             self.errors.update(fetch_cmd.errors)
             if not self.errors:
                 dct = json.loads(fetch_cmd.result.content)
-                cmd_parallel = CommandParallel(GetMainUserByEmail(dct['email']) , GetPasswordlessUser(dct['id']))
+                cmd_parallel = CommandParallel(GetMainUserByEmail(dct['email']), GetPasswordlessUser(dct['id']))
                 cmd_parallel.execute()
                 main_user, passwordless_user = cmd_parallel[0].result, cmd_parallel[1].result
                 if passwordless_user:
-                    main_user = SingleDestinationSearch(ExternalToMainUser, passwordless_user).execute().result
+                    main_user = MainUserSearch(passwordless_user).execute().result
                 elif main_user:
                     passwordless_user_key = PasswordlessUser(external_id=dct['id']).put()
                     self._to_commit = ExternalToMainUser(origin=passwordless_user_key, destination=main_user.key)
